class Debugging:

    def isvalid(self, apicall):
        if apicall.get("success") != None:
            return True
        elif apicall.get("err") != None:
            return False

    def missmatch(self, apicall, user):
        if apicall.get("success") != None:
            if apicall["success"]["uuid"] == user:
                return False
            else:
                return True
        else:
            return None

    def errmsg(self, apicall):
        if apicall.get("err") != None:
            return f'{apicall["err"]}'
        else:
            return "No error message provided. JSON response is valid" 



import requests

def checkvalid(apicall):
    if apicall.get("success") != None:
        return True

class Statistics:

    def request(self, user):
        try:
            req = requests.get(f"https://api.2b2tlarp.org/user/stats/{(user)}").json()
            return req
        except:
            print("""
-----------------------
Critical Library error.
Err: Module API; class Statistics in function 'request'
An error occurred in the Library.
This is not a bug in your code.
Please open an issue on the github repository.
Sorry for the inconvenience.
-----------------------

""")
            return None

    def raw(self, apicall):
        return apicall

    def uuid(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["uuid"]
            return data
        else:
            return None

    def ratio(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["ratio"]
            return data
        else:
            return None

    def kills(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["kills"]
            return data
        else:
            return None

    def deaths(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["deaths"]
            return data
        else:
            return None

    def joindate(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["joindate"]
            return data
        else:
            return None

    def lastplayed(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["lastPlayed"]
            return data
        else:
            return None

    def leaves(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["leaves"]
            return data
        else:
            return None

    def enderpearls(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["enderPearls"]
            return data
        else:
            return None

    def crystal(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["crystal"]
            return data
        else:
            return None
    
    def damage(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["damage"]
            return data
        else:
            return None

    def damagetaken(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["damageTaken"]
            return data
        else:
            return None

    def mobkills(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["mobkills"]
            return data
        else:
            return None

    def jumps(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["jumps"]
            return data
        else:
            return None

    def timesincedeath(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["timeSinceDeath"]
            return data
        else:
            return None

    def score(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["score"]
            return data
        else:
            return None

    def health(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["health"]
            return data
        else:
            return None

    def playtime(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["playTime"]
            return data
        else:
            return None

    def recordtime(self, apicall):
        if checkvalid(apicall):
            data = apicall["success"]["lastUpdated"]
            return data
        else:
            return None





from setuptools import setup, find_packages

VERSION = '0.1.2' 
DESCRIPTION = 'API Wrapper for 5b5t.org'
LONG_DESCRIPTION = """Automate and simplify API requests for 5b5t.org.
A detailed documentation can be found at https://github.com/ScobraScope/stats5b5t-documentation
"""

setup(
       # the name must match the folder name 'verysimplemodule'
        name="stats5b5t", 
        version=VERSION,
        author="ScobraScope",
        url="https://github.com/ScobraScope/stats5b5t",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[
            "requests"
        ],
        keywords=['python', 'api', '5b5t', 'minecraft'],
        classifiers= [
            "Operating System :: Microsoft :: Windows",
            "Intended Audience :: Developers",
            "Intended Audience :: Education",
            "Natural Language :: English",
            "Programming Language :: Python :: 3.9",
            "Topic :: Games/Entertainment", 
        ]
)